collect_all_sql_files

Function collect_all_sql_files 

pub(crate) fn collect_all_sql_files(
    directory: &Path,
) -> Result<Vec<ObjectFiles>, LoadError>
Collect all .sql files from a directory grouped by object name without resolving.

Returns all variants (default + all profile overrides) for each object. This is used to load and validate all profile variants before resolving.